from fastapi import FastAPI, Request
from fastapi.responses import HTMLResponse, JSONResponse, FileResponse
from fastapi.staticfiles import StaticFiles
import os
import json
import base64

app = FastAPI(title="MidTownPlaydio")

# Directory to store static files
STATIC_DIR = os.path.join(os.path.dirname(os.path.abspath(__file__)), "static")
os.makedirs(STATIC_DIR, exist_ok=True)

# Generate index.html
def generate_index_html():
    with open(os.path.join(STATIC_DIR, 'index.html'), 'w') as f:
        f.write('''
        <!DOCTYPE html>
        <html>
        <head>
            <title>MidTownPlaydio</title>
            <meta charset="UTF-8">
            <meta name="viewport" content="width=device-width, initial-scale=1.0">
            <link rel="manifest" href="/manifest.json">
            <meta name="theme-color" content="#ffffff">
            <style>
                body {
                    font-family: Arial, sans-serif;
                    margin: 0;
                    padding: 0;
                    display: flex;
                    flex-direction: column;
                    align-items: center;
                    justify-content: center;
                    height: 100vh;
                    background-color: #f0f0f0;
                }
                .container {
                    text-align: center;
                    padding: 20px;
                }
                h1 {
                    color: #333;
                }
            </style>
        </head>
        <body>
            <div class="container">
                <h1>MidTownPlaydio</h1>
                <iframe src="https://midtownradiokw.airtime.pro/player" width="300" height="200" allow="autoplay"></iframe>
            </div>
            <script>
                if ('serviceWorker' in navigator) {
                    window.addEventListener('load', function() {
                        navigator.serviceWorker.register('/service-worker.js').then(function(registration) {
                            console.log('ServiceWorker registration successful with scope: ', registration.scope);
                        }, function(err) {
                            console.log('ServiceWorker registration failed: ', err);
                        });
                    });
                }
            </script>
        </body>
        </html>
        ''')

# Generate manifest.json
def generate_manifest_json():
    manifest = {
        "name": "MidTownPlaydio",
        "short_name": "MidTownPlaydio",
        "start_url": "/",
        "display": "standalone",
        "background_color": "#ffffff",
        "theme_color": "#ffffff",
        "icons": [
            {
                "src": "/icon.png",
                "sizes": "192x192",
                "type": "image/png"
            }
        ]
    }

    with open(os.path.join(STATIC_DIR, 'manifest.json'), 'w') as f:
        json.dump(manifest, f, indent=4)

# Generate service-worker.js
def generate_service_worker():
    with open(os.path.join(STATIC_DIR, 'service-worker.js'), 'w') as f:
        f.write('''
        const CACHE_NAME = 'midtownplaydio-cache-v1';
        const urlsToCache = [
            '/',
            '/index.html',
            '/manifest.json',
            '/icon.png'
        ];

        self.addEventListener('install', event => {
            event.waitUntil(
                caches.open(CACHE_NAME).then(cache => {
                    console.log('Opened cache');
                    return cache.addAll(urlsToCache);
                })
            );
        });

        self.addEventListener('fetch', event => {
            event.respondWith(
                caches.match(event.request).then(response => {
                    // Cache hit - return response
                    if (response) {
                        return response;
                    }
                    return fetch(event.request);
                })
            );
        });

        self.addEventListener('activate', event => {
            const cacheWhitelist = [CACHE_NAME];
            event.waitUntil(
                caches.keys().then(cacheNames => {
                    return Promise.all(
                        cacheNames.map(cacheName => {
                            if (cacheWhitelist.indexOf(cacheName) === -1) {
                                return caches.delete(cacheName);
                            }
                        })
                    );
                })
            );
        });
        ''')

# Create a simple placeholder icon
def create_placeholder_icon():
    # A minimal 1x1 transparent PNG
    minimal_png_base64 = "iVBORw0KGgoAAAANSUhEUgAAAMAAAADAAQMAAABoEv5EAAAABlBMVEUAAAD///+l2Z/dAAAANklEQVRIx+3IMQEAAAgDoPnX3hiu20CDBnbmFVFRUVFRUVFRUVFRUVFRUVFRUVFRUVFRUVFReQMHaigbWzGsIQAAAABJRU5ErkJggg=="
    png_data = base64.b64decode(minimal_png_base64)
    
    with open(os.path.join(STATIC_DIR, 'icon.png'), 'wb') as f:
        f.write(png_data)

# Generate all static files on startup
@app.on_event("startup")
async def startup_event():
    generate_index_html()
    generate_manifest_json()
    generate_service_worker()
    create_placeholder_icon()

# Mount static files
app.mount("/", StaticFiles(directory=STATIC_DIR, html=True), name="static")

# Health check endpoint
@app.get("/health", status_code=200)
async def health_check():
    return {"status": "ok"}

# If the file is executed directly, run a development server
if __name__ == "__main__":
    import uvicorn
    uvicorn.run(app, host="0.0.0.0", port=3000) 